ScreenManager

Struct ScreenManager 

pub struct ScreenManager<'sm> { /* private fields */ }
ScreenManager is responsible for redirecting the user to the screen it should be seeing at any point by the application, it is the entity behind navigation

Implementations

Source

impl<'sm> ScreenManager<'sm>

pub fn new( size: Rect, colors: &'sm Colors, collections: Vec<Collection>, config: &'sm Config, dry_run: bool, ) -> Result<Self>

pub fn handle_command(&mut self, command: Command)