pub struct ScreenManager<'sm> { /* private fields */ }Expand description
ScreenManager is responsible for redirecting the user to the screen it should be seeing at any point by the application, it is the entity behind navigation
Implementations
Sourceimpl<'sm> ScreenManager<'sm>
impl<'sm> ScreenManager<'sm>